#
# spec file for package perl-Test-MockModule
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-MockModule
Name:           perl-Test-MockModule
Version:        0.178.0
Release:        1.1
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Override subroutines in a module for unit testing
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/G/GF/GFRANKS/%{cpan_name}-v%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Build) >= 0.38
BuildRequires:  perl(SUPER) >= 1.20
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Warnings)
Requires:       perl(SUPER) >= 1.20
%{perl_requires}

%description
'Test::MockModule' lets you temporarily redefine subroutines in other
packages for the purposes of unit testing.

A 'Test::MockModule' object is set up to mock subroutines for a given
module. The object remembers the original subroutine so it can be easily
restored. This happens automatically when all MockModule objects for the
given module go out of scope, or when you 'unmock()' the subroutine.

%prep
%autosetup  -n %{cpan_name}-v%{version}

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md
%license LICENSE

%changelog
* Sat Apr 27 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.178.0
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.178.0
  - 6724a30 - Simplify CI workflow - Nicolas R
  - 1801372 - Multiple improvements -  Nicolas R
  - e97e316 - Add protection to _replace_sub - Nicolas R
* Wed Sep  8 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.177.0
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.177.0
  - 35f0d0b Update changelog - Geoff Franks
  - 1d5b485 Move test modules from build to test requires - Olaf Alders
  - 78afe10 Clean up changelog - Geoff Franks
  v0.277.0
  - Move test modules from build to test requires - Olaf Alders
* Wed Jan  6 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.176.0
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.176.0
  - 3ba8bc7 lexically scoped strictness - David Cantrell
  - e57fc5a Update ci with dockerhub auth - Geoff Franks
  - bfe1e63 Update GitHub workflow with deprecated add-path - Nicolas R
  vX.XXX.X
  - XXXXXXX 'strict' mode is now lexically scoped
* Fri Sep 18 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.175.0
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.175.0
  - 964aa2a Ignore CI files and whitesource - Nicolas R
* Tue Sep 15 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.174.0
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.174.0
  - cf65e7c Fix typo in pod - nima
* Sat Jun 13 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.173.0
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.173.0
  - 4dacd82 Add warning when 'unmock' called without arguments - Matthew Hughes
  - b20dc7c import warns when using unknown argument - Nicolas R
  - 3b217ba Fix windows CI by installing SUPER - Nicolas R
  - 0ef70c5 Add .whitesource configuration file - whitesource-bolt-for-github[bot]
* Thu Feb 20 2020 <timueller+perl@suse.de>
- updated to 0.172.0
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.172.0
  - 7558aa9 Make sure we can redefine a function in 'main' - Nicolas R
  - 0538fe1 Plug GitHub workflow as additional CI - Nicolas R
  - 0e9d90b update parallel to use in_parallel instead ofaggregate - Geoff Franks
* Mon Oct 21 2019 <timueller+perl@suse.de>
- updated to 0.171.0
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.171.0
  - 89dc5c0 Fixes #25 - mocking core::global no longer fails trying to load the module - Geoff Franks
  - 9bb081a update ci for fewer infinite loops - Geoff Franks
  - 289d014 Update release notes for all the newly merged PRs - Geoff Franks
  - fef9e74 Allow chaining of new with mock, redefine, define - Nicolas Rochelemagne
  - e136131 Prevent redefine() from triggering DESTROY. - Felipe Gasper
  - 311f6b4 Adjust Travis CI configuration to use travis-perl.github.io - Nicolas Rochelemagne
  - 2bed3e2 Add strict mode to ban the use of noop and mock. - Todd Rinaldo
  - 0298d8d Provide define method so the mock method is unneeded in tests. - Todd Rinaldo
  v0.171.0
  - allow chaining of new with mock, redefine, define
  - redefine() no longer triggers errors if the object being mocked is not a hashref
  - Adds a define() method for mocking new functions that do not exist. Throws an
    error if a function does exist.
  - Adds `strict` mode to prevent usage of noop() and mock() functions, and force
    the usage of define/redefine if desired.:
    ```
    use Test::MockModule qw/strict/;
    ```
  - Mocking CORE::GLOBAL no longer throws errors indicating CORE::GLOBAL should have
    been installed/loaded
* Thu Sep 20 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.170.0
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.170.0
  - 182d066 Fix versioning for semver conversion + PAUSE - Geoff Franks
  - 4afeedf release v0.17.0 - CI Bot
  - 9df8ac4 Add CI pipeline for releasing to cpan - Geoff Franks
  - 577350e Pod - provide a code snippet for original usage - Nicolas R
  - 3e4ec72 Add missing pod entries - Geoff Franks
  v0.16
  - Fixes an issue where warnings were thrown for mismatched prototypes,
    when mocking a prototyped function.
    Thanks @toddr for the fix!
* Sat May 19 2018 coolo@suse.com
- updated to 0.15
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.15
  - Fixes a minor bug in the release tarball
* Sun May  6 2018 coolo@suse.com
- updated to 0.14
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.14
  - Fixes a bug where the `redefine()` function was dying when attempting to
    mock a function that was defined further up a module's inheritance chain.
    It now only dies when the mocked function does not exist in the module being
    mocked, or any of its parent modules. Thanks @atoomic for the improvement!
* Fri Oct  6 2017 coolo@suse.com
- updated to 0.13
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.13
  - Added the `redefine()` function. It works just like `mock()`, except if the
    method being mocked doesn't exist, it causes a panic. Many thanks to Felipe
    Gasper for this feature!
* Thu Jul 13 2017 coolo@suse.com
- updated to 0.12
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.12
  - Added the `noop()` function to make mocking noops easier. Thanks for the PR,
    Ali Zia!
  v0.11 2016-10-27
  - Various housekeeping, testing and minor fixes, courtesy of Paul Cochrane, thanks!
* Wed Oct 28 2015 coolo@suse.com
- updated to 0.11
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
* Sun Jun  7 2015 coolo@suse.com
- updated to 0.10
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
* Thu Apr 16 2015 coolo@suse.com
- set license to GPL-3.0+
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.09
  see /usr/share/doc/packages/perl-Test-MockModule/Changes
  v0.08 2015-03-15
  - Ensure LICENSE autogenerates for distribution, fixed license issues in Build.PL
  v0.08 2015-03-14
  - Updated README with correct instructions now that we use Build.PL
  v0.07 2015-03-14
  - Updated docs for more clarity when handling objects of mocked classes.
  v0.06 2015-03-07
  - unmock() on inherited subroutines will dispatch to the parent module,
    rather than replace the local subroutine with the parent's subroutine
    from the time of mocking (RT77439)
* Thu Feb 12 2015 coolo@suse.com
- fix license
* Thu Apr 21 2011 coolo@opensuse.org
- initial package 0.05
  * created by cpanspec 1.78.04
